@@ -84,3 +84,12 @@ class PythonVersionTagger(TaggerInterface):
                 error = e
         else:
             raise error
+
+
+class PythonProjectTagger(TaggerInterface):
+    @staticmethod
+    def tag_value(container) -> str:
+        pyproject = DockerRunner.run_simple_command(container, "cat pyproject.toml", False).split("\n")
+        for line in pyproject:
+            if line.startswith("version"):
+                return line.split("=")[1].strip(' "')
